Package: SVMDO
Title: Identification of Tumor-Discriminating mRNA Signatures via
        Support Vector Machines Supported by Disease Ontology
Version: 1.11.0
Date: 2024-08-30
Authors@R: 
    c(person(given = "Mustafa Erhan",
	family = "Ozer",
    role = c("aut","cre"),
    comment = c(ORCID = "0000-0002-1572-8008"),
    email = "erhanozer19@marun.edu.tr"),
    person(given = "Pemra",
    family = "Ozbek Sarica",
    role = "aut",
    email = "pemra.ozbek@marmara.edu.tr"),
    person(given = "Kazim Yalcin",
    family = "Arga",
    role = "aut",
    email = "kazim.arga@marmara.edu.tr"))      
Depends: R(>= 4.4), shiny (>= 1.7.4)
Imports: shinyFiles (>= 0.9.3), shinytitle (>= 0.1.0), golem (>=
        0.3.5), nortest (>= 1.0-4), e1071 (>= 1.7-12), BSDA (>= 1.2.1),
        data.table (>= 1.14.6), sjmisc (>= 2.8.9), klaR (>= 1.7-1),
        caTools (>= 1.18.2), caret (>= 6.0-93), survival (>= 3.4-0), DT
        (>= 0.33.0), DOSE (>= 3.24.2), AnnotationDbi (>= 1.60.0),
        org.Hs.eg.db (>= 3.16.0), dplyr (>= 1.0.10),
        SummarizedExperiment (>= 1.28.0), grDevices, graphics, stats,
        utils
Description: It is an easy-to-use GUI using disease information for detecting 
            tumor/normal sample discriminating gene sets from differentially 
            expressed genes. Our approach is based on an iterative algorithm 
            filtering genes with disease ontology enrichment analysis and wilk 
            and wilks lambda criterion connected to SVM classification model 
            construction. Along with gene set extraction, SVMDO also provides 
            individual prognostic marker detection. The algorithm is designed 
            for FPKM and RPKM normalized RNA-Seq transcriptome datasets. 
RoxygenNote: 7.3.2
biocViews: GeneSetEnrichment, DifferentialExpression, GUI,
        Classification, RNASeq, Transcriptomics, Survival
NeedsCompilation: no
License: GPL-3
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
Suggests: BiocStyle, knitr, rmarkdown, testthat (>= 3.1.6)
VignetteBuilder: knitr
Config/testthat/edition: 3
BugReports: https://github.com/robogeno/SVMDO/issues
git_url: https://git.bioconductor.org/packages/SVMDO
git_branch: devel
git_last_commit: 2bc7e27
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
Packaged: 2025-11-01 00:32:13 UTC; biocbuild
Author: Mustafa Erhan Ozer [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1572-8008>),
  Pemra Ozbek Sarica [aut],
  Kazim Yalcin Arga [aut]
Maintainer: Mustafa Erhan Ozer <erhanozer19@marun.edu.tr>
