#' @title SVMDO
#' @return Providing package-level manual page
#' 
#' @description Package Description:
#' It is an easy-to-use GUI using disease information for detecting 
# 'tumor/normal sample discriminating gene sets from differentially 
#' expressed genes. Our approach is based on an iterative algorithm 
#' filtering genes with disease ontology enrichment analysis and wilk 
#' and wilks lambda criterion connected to SVM classification model 
#' construction. Along with gene set extraction, SVMDO also provides 
#' individual prognostic marker detection. The algorithm is designed 
#' for FPKM and RPKM normalized RNA-Seq transcriptome datasets. 

