% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/globals.R
\name{globals}
\alias{globals}
\title{SVMDO}
\value{
Including script files and global variables of GUI required to be
initiated at the runApp file execution
}
\description{
SVMDO
}
