% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_show_ui.R
\name{plot_show_ui}
\alias{plot_show_ui}
\alias{innerUI_plot_show}
\title{SVMDO}
\usage{
innerUI_plot_show(id)
}
\arguments{
\item{id}{connection input}
}
\value{
UI section of providing information about total number of survival plots for visualization
}
\description{
SVMDO
}
